"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.newReplies = void 0;
const util_1 = require("./util");
function newReplies() {
    return (ctx, next) => {
        function makeReply(extra) {
            var _a;
            const ret = extra || {};
            ret.reply_to_message_id = (_a = ctx.message) === null || _a === void 0 ? void 0 : _a.message_id;
            return ret;
        }
        // Disable replyWithChatAction in favour of respondWithChatAction
        ctx.replyWithChatAction = function () {
            throw new TypeError('ctx.replyWithChatAction is removed, use respondWithChatAction instead');
        };
        ctx.reply = function reply(text, extra) {
            (0, util_1.assert)(ctx, 'chat', 'reply');
            return ctx.respond(text, makeReply(extra));
        };
        ctx.replyWithAnimation = function replyWithAnimation(animation, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithAnimation');
            return ctx.telegram.sendAnimation(ctx.chat.id, animation, makeReply(extra));
        };
        ctx.replyWithAudio = function replyWithAudio(audio, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithAudio');
            return ctx.telegram.sendAudio(ctx.chat.id, audio, makeReply(extra));
        };
        ctx.replyWithContact = function replyWithContact(phoneNumber, firstName, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithContact');
            return ctx.telegram.sendContact(ctx.chat.id, phoneNumber, firstName, makeReply(extra));
        };
        ctx.replyWithDice = function replyWithDice(extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithDice');
            return ctx.telegram.sendDice(ctx.chat.id, makeReply(extra));
        };
        ctx.replyWithDocument = function replyWithDocument(document, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithDocument');
            return ctx.telegram.sendDocument(ctx.chat.id, document, makeReply(extra));
        };
        ctx.replyWithGame = function replyWithGame(gameName, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithGame');
            return ctx.telegram.sendGame(ctx.chat.id, gameName, makeReply(extra));
        };
        ctx.replyWithHTML = function replyWithHTML(html, extra) {
            var _a;
            (0, util_1.assert)(ctx, 'chat', 'replyWithHTML');
            return ctx.telegram.sendMessage(ctx.chat.id, html, {
                parse_mode: 'HTML',
                reply_to_message_id: (_a = ctx.message) === null || _a === void 0 ? void 0 : _a.message_id,
                ...extra,
            });
        };
        ctx.replyWithInvoice = function replyWithInvoice(invoice, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithInvoice');
            return ctx.telegram.sendInvoice(ctx.chat.id, invoice, makeReply(extra));
        };
        ctx.replyWithLocation = function replyWithLocation(latitude, longitude, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithLocation');
            return ctx.telegram.sendLocation(ctx.chat.id, latitude, longitude, makeReply(extra));
        };
        ctx.replyWithMarkdown = function replyWithMarkdown(markdown, extra) {
            var _a;
            (0, util_1.assert)(ctx, 'chat', 'replyWithMarkdown');
            return ctx.telegram.sendMessage(ctx.chat.id, markdown, {
                parse_mode: 'Markdown',
                reply_to_message_id: (_a = ctx.message) === null || _a === void 0 ? void 0 : _a.message_id,
                ...extra,
            });
        };
        ctx.replyWithMarkdownV2 = function replyWithMarkdownV2(markdown, extra) {
            var _a;
            (0, util_1.assert)(ctx, 'chat', 'replyWithMarkdownV2');
            return ctx.telegram.sendMessage(ctx.chat.id, markdown, {
                parse_mode: 'MarkdownV2',
                reply_to_message_id: (_a = ctx.message) === null || _a === void 0 ? void 0 : _a.message_id,
                ...extra,
            });
        };
        ctx.replyWithPhoto = function replyWithPhoto(photo, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithPhoto');
            return ctx.telegram.sendPhoto(ctx.chat.id, photo, makeReply(extra));
        };
        ctx.replyWithPoll = function replyWithPoll(question, options, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithPoll');
            return ctx.telegram.sendPoll(ctx.chat.id, question, options, makeReply(extra));
        };
        ctx.replyWithQuiz = function replyWithQuiz(question, options, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithQuiz');
            return ctx.telegram.sendQuiz(ctx.chat.id, question, options, makeReply(extra));
        };
        ctx.replyWithSticker = function replyWithSticker(sticker, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithSticker');
            return ctx.telegram.sendSticker(ctx.chat.id, sticker, makeReply(extra));
        };
        ctx.replyWithVenue = function replyWithVenue(latitude, longitude, title, address, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithVenue');
            return ctx.telegram.sendVenue(ctx.chat.id, latitude, longitude, title, address, makeReply(extra));
        };
        ctx.replyWithVideo = function replyWithVideo(video, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithVideo');
            return ctx.telegram.sendVideo(ctx.chat.id, video, makeReply(extra));
        };
        ctx.replyWithVideoNote = function replyWithVideoNote(videoNote, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithVideoNote');
            return ctx.telegram.sendVideoNote(ctx.chat.id, videoNote, makeReply(extra));
        };
        ctx.replyWithVoice = function replyWithVoice(voice, extra) {
            (0, util_1.assert)(ctx, 'chat', 'replyWithVoice');
            return ctx.telegram.sendVoice(ctx.chat.id, voice, makeReply(extra));
        };
        return next();
    };
}
exports.newReplies = newReplies;
